@@ -43,7 +43,7 @@ $lang = array_merge($lang, array(
 	'TRANSLATION_INFO'	=> 'Vertaald door <a href="http://www.phpBBservice.nl/">phpBBservice.nl</a>.',
 	'DIRECTION'			=> 'ltr',
 	'DATE_FORMAT'		=> '|d M Y|',	// 01 Jan 2007 (with Relative days enabled)
-	'USER_LANG'			=> 'nl',
+	'USER_LANG'			=> 'nl-x-formal',
 
 	'1_DAY'			=> '1 dag',
 	'1_MONTH'		=> '1 maand',
@@ -165,6 +165,7 @@ $lang = array_merge($lang, array(
 	'EMPTY_MESSAGE_SUBJECT'				=> 'U moet een onderwerptitel invoeren voordat u een nieuw bericht kunt plaatsen.',
 	'ENABLED'							=> 'Ingeschakeld',
 	'ENCLOSURE'							=> 'Bijsluiten',
+	'ENTER_USERNAME'					=> 'Voer gebruikersnaam in',
 	'ERR_CHANGING_DIRECTORY'			=> 'Kon de directory niet wijzigen.',
 	'ERR_CONNECTING_SERVER'				=> 'Er is een fout opgetreden bij het maken van een verbinding met de server.',
 	'ERR_JAB_AUTH'						=> 'Kon niet aanmelden op de Jabber-server.',
@@ -200,6 +201,7 @@ $lang = array_merge($lang, array(
 	'FORUM_RULES_LINK'		=> 'Klik hier om de forumregels te bekijken',
 	'FROM'					=> 'van',
 	'FSOCK_DISABLED'		=> 'De actie kon niet worden uitgevoerd, omdat de <code>fsockopen</code>-functie is uitgeschakeld of dat de opgevraagde server niet kon worden gevonden.',
+	'FSOCK_TIMEOUT'			=> 'Een tijdsonderbreking heeft zich voorgedaan tijdens het lezen van de netwerk-stream.',
 
 	'FTP_FSOCK_HOST'				=> 'FTP-host',
 	'FTP_FSOCK_HOST_EXPLAIN'		=> 'FTP-server die gebruikt wordt om verbinding te maken met uw site.',
@@ -649,9 +651,13 @@ $lang = array_merge($lang, array(
 	'UNREAD_MESSAGES'			=> 'Ongelezen berichten',
 	'UNREAD_PM'					=> '<strong>%d</strong> ongelezen bericht',
 	'UNREAD_PMS'				=> '<strong>%d</strong> ongelezen berichten',
-    'UNREAD_POST'               => 'Ongelezen bericht',
-    'UNREAD_POSTS'              => 'Ongelezen berichten',	
+	'UNREAD_POST'				=> 'Ongelezen bericht',
+	'UNREAD_POSTS'				=> 'Ongelezen berichten',
 	'UNWATCHED_FORUMS'			=> 'U bent niet meer geabonneerd op de geselecteerde forums.',
+	'UNWATCH_FORUM_CONFIRM'		=> 'Weet u zeker dat u het abonnement wilt stopzetten van dit forum?',
+	'UNWATCH_FORUM_DETAILED'	=> 'Weet u zeker dat u het abonnement van het forum “%s” wilt stopzetten?',
+	'UNWATCH_TOPIC_CONFIRM'		=> 'Weet u zeker dat u het abonnement wilt stopzetten van dit onderwerp?',
+	'UNWATCH_TOPIC_DETAILED'	=> 'Weet u zeker dat u het abonnement van het onderwerp “%s” wilt stopzetten?',
 	'UNWATCHED_TOPICS'			=> 'U bent niet meer geabonneerd op de geselecteerde onderwerpen.',
 	'UNWATCHED_FORUMS_TOPICS'	=> 'U bent niet meer geabonneerd op de geselecteerde forums en onderwerpen.',
 	'UPDATE'					=> 'Update',
@@ -698,6 +704,10 @@ $lang = array_merge($lang, array(
 	'VISIT_WEBSITE'				=> 'Website bezoeken',
 
 	'WARNINGS'			=> 'Waarschuwingen',
+	'WATCH_FORUM_CONFIRM'	=> 'Weet u zeker dat u zich wilt abonneren op dit forum?',
+	'WATCH_FORUM_DETAILED'	=> 'Weet u zeker dat u zich wilt abonneren op het forum “%s”?',
+	'WATCH_TOPIC_CONFIRM'	=> 'Weet u zeker dat u zich wilt abonneren op dit onderwerp?',
+	'WATCH_TOPIC_DETAILED'	=> 'Weet u zeker dat u zich wilt abonneren op het onderwerp “%s”?',
 	'WARN_USER'			=> 'Gebruiker waarschuwen',
 	'WELCOME_SUBJECT'	=> 'Welkom op het %s-forum',
 	'WEBSITE'			=> 'Website',
