@@ -38,14 +38,16 @@ if (empty($lang) || !is_array($lang))
 // Privacy policy and T&C
 $lang = array_merge($lang, array(
 	'TERMS_OF_USE_CONTENT'	=> '
-		Door het bezoeken van “%1$s”  (inbegrepen “wij”, “ons” , “onze” , “%1$s” , “%2$s” ), gaat u automatisch akkoord met de volgende voorwaarden. Als u niet akkoord gaat met de voorwaarden, bezoek of gebruik “%1$s” dan niet langer. Wij hebben het recht om de voorwaarden op ieder moment te wijzigen en zullen u daar zoveel mogelijk van op de hoogte houden. Het is echter wel aan te raden zelf de voorwaarden te controleren op wijzigingen. Als u niet akkoord gaat met de wijzigingen, maak dan niet langer gebruik meer van &ldquo;%1$s&rdquo;. Als u gebruik blijft maken van “%1$s”, gaat u automatisch akkoord met de wijzigingen.<br />
+		Door het bezoeken van “%1$s”, gaat u automatisch akkoord met bepaalde voorwaarden.
+		Kunt u niet akkoord gaan met deze voorwaarden, bezoek of gebruik “%1$s” dan niet langer. Beheerder(s) en moderator(en) hebben het recht om de voorwaarden op ieder moment te wijzigen. De gebruikers zullen hiervan zoveel mogelijk op de hoogte worden gehouden. Het is echter aan te raden om zelf de voorwaarden regelmatig te controleren op wijzigingen. Kunt u niet akkoord gaan met deze wijzigingen, maak dan niet langer gebruik van “%1$s”. Blijft u gebruik maken van “%1$s”, dan gaat u automatisch akkoord met de wijzigingen.<br />
 		<br />
-		Dit forum draait op phpBB (hierna “zij”, “hen”, “hun”, “phpBB software”, “www.phpBB.com”, “www.phpBBservice.nl”, “phpBB Groep”, “phpBB Teams”) wat een bulletinboard oplossing is, dat is uitgebracht onder de “<a href="http://opensource.org/licenses/gpl-license.php">General Public License</a>” (hierna “GPL”) en kan gedownload worden via <a href="http://www.phpBB.com/">www.phpBB.com</a> en de Nederlandstalige website <a href="http://www.phpBBservice.nl/">www.phpBBservice.nl</a>. De phpBB software vermakkelijkt alleen de internet gebaseerde discussies, de phpBB Groep is niet verantwoordelijk voor de inhoud en/of de houding wat er is toegestaan en wat niet. Voor verdere informatie over phpBB, bezoek dan hun website: <a href="http://www.phpBB.com/">http://www.phpBB.com</a> of de Nederlandstalige website <a href="http://www.phpBBservice.nl/">http://www.phpBBservice.nl</a>.<br />
+		Dit forum draait op phpBB. phpBB is een bulletinboard oplossing dat is uitgebracht onder de “<a href="http://opensource.org/licenses/gpl-license.php">General Public License</a>” (hierna “GPL”) en kan gedownload worden via <a href="http://www.phpBB.com/">www.phpBB.com</a> en via de Nederlandstalige website <a href="http://www.phpBBservice.nl/">www.phpBBservice.nl</a>. De phpBB-software vergemakkelijkt alleen de internet gebaseerde discussies. De phpBB-groep is niet verantwoordelijk voor de inhoud en/of de houding van wat er is toegestaan en wat niet. Meer informatie over phpBB, kunt u vinden op de volgende website; <a href="http://www.phpBB.com/">http://www.phpBB.com</a> of de Nederlandstalige website <a href="http://www.phpBBservice.nl/">http://www.phpBBservice.nl</a>.<br />
 		<br />
-		U gaat ermee akkoord geen kwetsende, obscene, vulgaire, lasterlijke, haatdragende, dreigende, seksueel geörienteerde of anderzijds verwerpelijke berichten te plaatsen, die van toepassing zijnde regels en/of wetten schenden die gelden voor uw land, het land waar “%1$s” is gehost of de internationale wetgeving.
-		Het plaatsen van dergelijke berichten kan ertoe leiden dat u onmiddelijk en permanent wordt verbannen van deelname aan dit forum, en uw serviceprovider kan geïnformeerd worden. Het IP-adres van alle berichten wordt opgeslagen om deze voorwaarden te kunnen waarborgen.
-		U gaat akkoord dat “%1$s” het recht hebben om onderwerpen te verwijderen, wijzigen, verplaatsen of sluiten wanneer zij dit nodig vinden. Als gebruiker gaat u ermee akkoord dat de informatie die u bij ons invoert wordt opgeslagen in een database. Hoewel deze informatie niet aan een derde partij zal worden verstrekt zonder uw toestemming aan de webmaster, kunnen “%1$s”of phpBB niet verantwoordelijk worden gehouden voor een hackpoging die ertoe leidt dat de gegevens vrijkomen.
-	',
+		U gaat akkoord met het volgende: Geen kwetsende, obscene, vulgaire, lasterlijke, haatdragende, dreigende, seksueel georiënteerde of anderzijds verwerpelijke berichten te plaatsen, die de van toepassing zijnde regels en/of wetten schenden die gelden voor jouw land, het land waar “%1$s” is gehost of de internationale wetgeving.
+		Het plaatsen van dergelijke berichten kan ertoe leiden dat u met onmiddellijke ingang en permanent wordt verbannen van dit forum. Tevens kan uw serviceprovider worden ingelicht.
+		De IP-adressen van alle berichten worden opgeslagen om deze voorwaarden te kunnen waarborgen.
+		U gaat ermee akkoord dat beheerder(s) en moderator(en) het recht hebben om onderwerpen te verwijderen te wijzigen te verplaatsen of te sluiten wanneer zij dit nodig achten. Als gebruiker gaat u ermee akkoord dat de informatie die u bij ons invoert wordt opgeslagen in een database. Hoewel deze informatie niet aan een derde partij zal worden verstrekt zonder uw toestemming, kunnen  beheerder(s) en moderator(en) of phpBB niet verantwoordelijk worden gehouden voor een hackpoging die ertoe kan leiden dat de gegevens vrijkomen.
+    ',
 
 	'PRIVACY_POLICY'	=> '
 		Dit beleid legt in detail uit hoe “%1$s” samen met zijn verbonden diensten en bedrijven (hierna “wij”, “ons”, “onze”, “%1$s”, “%2$s”) en phpBB (hierna “zij”, “hun”, “zijn”, “phpBB software”, “www.phpBB.com”, “www.phpBBservice.nl”, “phpBB Groep”, “phpBB Teams”) de informatie die wordt verzameld gedurende een bezoek aan dit forum wordt gebruikt (hierna “uw informatie”).<br />
@@ -143,6 +145,7 @@ $lang = array_merge($lang, array(
 	'CURRENT_IMAGE'				=> 'Huidige afbeelding',
 	'CURRENT_PASSWORD'			=> 'Huidige wachtwoord',
 	'CURRENT_PASSWORD_EXPLAIN'	=> 'U moet uw huidige wachtwoord bevestigen als u het wilt veranderen, of als u uw e-mailadres of gebruikersnaam hebt gewijzigd.',
+	'CUR_PASSWORD_EMPTY'		=> 'U heeft niet uw huidige wachtwoord ingevoerd.',
 	'CUR_PASSWORD_ERROR'		=> 'Het huidige wachtwoord dat u heeft ingevoerd is onjuist.',
 	'CUSTOM_DATEFORMAT'			=> 'Eigen formaat…',
 
@@ -272,9 +275,11 @@ $lang = array_merge($lang, array(
 	'MOVE_TO_FOLDER'				=> 'Verplaats naar map',
 	'MOVE_UP'						=> 'Verplaats omhoog',
 
+	'NEW_EMAIL_CONFIRM_EMPTY'		=> 'U heeft niet het bevestigings-e-mailadres opgegeven.',
 	'NEW_EMAIL_ERROR'				=> 'Het e-mailadres dat u heeft ingevoerd komt niet overeen.',
 	'NEW_FOLDER_NAME'				=> 'Nieuwe mapnaam',
 	'NEW_PASSWORD'					=> 'Nieuw wachtwoord',
+	'NEW_PASSWORD_CONFIRM_EMPTY'	=> 'U heeft niet een bevestigingswachtwoord opgegeven.',
 	'NEW_PASSWORD_ERROR'			=> 'De wachtwoorden die u heeft ingevoerd komen niet overeen.',
 	'NOTIFY_METHOD'					=> 'Notificatiemethode',
 	'NOTIFY_METHOD_BOTH'			=> 'Beide',
